
# Overview of documentation

This directory contains Markdown files used to generate online
documentation. The online documentation is built with
[Mkdocs](http://www.mkdocs.org/). 

# Docstrings

The DataFrames code has embedded docstrings that document the API
provided by this package. These docstrings are in Markdown format.

By convention, these docstrings normally have:

* A one- or two-line description

* Method definitions

* Several third-level headings as appropriate:

  - Constructors (for types)
  - Arguments - describe each argument in a bulleted list
  - Result
  - Details
  - Examples

* Other headings as needed

Also, `@comment` docstrings can be added for descriptive text or for
organizational headings. Organizational headings should be top-level
headings. Second-level headings are generated by default for each
documentation entry. Here is an example of such a heading:

```julia
@comment """
# Reshaping
"""
```

# Building the documentation

The main steps to build the documentation are:

1. Run the
   [build.jl script](https://github.com/JuliaStats/DataFrames.jl/blob/master/docs/build.jl)
   to extract the API documentation embedded in docstrings. These files are placed in DataFrames/docs/api. 

2. Run `mkdocs build` from the main DataFrames directory. This creates files in DataFrames/site.

To actually push the documentation to Github pages, use `mkdocs
gh-deploy`. We should only do this for a released version. Github pages
does not support multiple versions.

Note that neither the `docs/api/*` files nor the `site/*` files are
stored in the main DataFrames repository. The `site/*` files get
pushed to the gh-pages branch.

The build.jl script uses the
[Lexicon](https://github.com/MichaelHatherly/Lexicon.jl) package to
filter and extract docstrings from the source.

# Configuration

The
[mkdocs.yml](https://github.com/JuliaStats/DataFrames.jl/blob/master/mkdocs.yml)
file contains the configuration for Mkdocs. It is a YAML file that is
fairly easy to figure out.

The build.jl file determines how the embedded docstrings are pulled
out of the source code and organized. The docstrings are included in
the documentation in the order of entry, but other orderings are
possible.



